mercurial/patch.py
changeset 2875 3d6efcbbd1c9
parent 2874 4ec58b157265
child 2881 eab07a7b7491
--- a/mercurial/patch.py	Sat Aug 12 16:13:27 2006 -0700
+++ b/mercurial/patch.py	Sat Aug 12 16:40:12 2006 -0700
@@ -267,13 +267,13 @@
     if not node1:
         node1 = repo.dirstate.parents()[0]
     # reading the data for node1 early allows it to play nicely
     # with repo.changes and the revlog cache.
     change = repo.changelog.read(node1)
     mmap = repo.manifest.read(change[0])
     date1 = util.datestr(change[2])
 
     if not changes:
-        changes = repo.changes(node1, node2, files, match=match)
+        changes = repo.status(node1, node2, files, match=match)[:5]
     modified, added, removed, deleted, unknown = changes
     if files:
         def filterfiles(filters):
@@ -267,13 +267,13 @@
         node1 = repo.dirstate.parents()[0]
     # reading the data for node1 early allows it to play nicely
-    # with repo.changes and the revlog cache.
+    # with repo.status and the revlog cache.
     change = repo.changelog.read(node1)
     mmap = repo.manifest.read(change[0])